@@ -1,5 +1,7 @@
 from django import forms
 from django.contrib import admin
+from django.conf import settings
+from django.utils.translation import ugettext_lazy as _
 
 from mptt.admin import MPTTModelAdmin
 from mptt.forms import TreeNodeChoiceField
@@ -20,11 +22,10 @@ fiber_admin_site = FiberAdminSite(name='fiber_admin')
 class PageForm(forms.ModelForm):
 
     parent = TreeNodeChoiceField(queryset=Page.tree.all(), level_indicator=3*unichr(160), empty_label='---------', required=False)
-    url = forms.RegexField(label='URL', required=False, max_length=100, regex=r'^[-\w/\.\:"]+$',
-        help_text = 'Example: \'/section-1/products\' or \'products\' or \'"some_named_url"\'',
-        error_message = 'This value must contain only letters, numbers, underscores, dashes or slashes.')
-    redirect_page = TreeNodeChoiceField(queryset=Page.objects.filter(redirect_page__isnull=True), level_indicator=3*unichr(160), empty_label='---------', required=False)
-    template_name = forms.ChoiceField(choices=[['', '----------']]+list(TEMPLATE_CHOICES), required=False)
+    url = forms.RegexField(label=_('URL'), required=False, max_length=100, regex=r'^[-\w/\.\:"]+$',
+        help_text = _("""Example: '/section-1/products' or 'products' or '"some_named_url"'"""),
+        error_message = _('This value must contain only letters, numbers, underscores, dashes or slashes.'))
+    redirect_page = TreeNodeChoiceField(label=_('Redirect page'), queryset=Page.objects.filter(redirect_page__isnull=True), level_indicator=3*unichr(160), empty_label='---------', required=False)
 
     class Meta:
         model = Page
@@ -51,55 +52,70 @@ class PageContentItemInline(admin.TabularInline):
 
 class PageAdmin(MPTTModelAdmin):
 
-    def __init__(self, *args, **kwargs):
-        super(PageAdmin, self).__init__(*args, **kwargs)
-        # remove template choices, if there are no choices
-        if len(TEMPLATE_CHOICES) == 0:
-            self.fieldsets = (
-                (None, {'fields': ('parent', 'title', 'url', 'redirect_page')}),
-                ('Advanced options', {'classes': ('collapse',), 'fields': ('mark_current_regexes', 'show_in_menu', 'protected', 'metadata',)}),
-            )
-        else:
-            self.fieldsets = (
-                (None, {'fields': ('parent', 'title', 'url', 'redirect_page', 'template_name')}),
-                ('Advanced options', {'classes': ('collapse',), 'fields': ('mark_current_regexes', 'show_in_menu', 'protected', 'metadata',)}),
-            )
-
     form = PageForm
-
+    fieldsets = (
+        (None, {'fields': ('parent', 'title', 'url', 'redirect_page', 'template_name')}),
+        ('Advanced options', {'classes': ('collapse',), 'fields': ('mark_current_regexes', 'show_in_menu', 'protected', 'metadata',)}),
+    )
 
     inlines = (PageContentItemInline,)
-    list_display = ('title', 'url', 'redirect_page','get_absolute_url', 'move_links',)
+    list_display = ('title', 'view_on_site', 'url', 'redirect_page','get_absolute_url', 'action_links',)
     list_per_page = 1000
     search_fields = ('title', 'url', 'redirect_page')
 
-    def move_links(self, object):
-        move_up = u'\u2007'
-        move_down = u'\u2007'
+    def view_on_site(self, page):
+        view_on_site = ''
 
-        # first child cannot be moved up
-        if (not object.is_first_child()):
-            move_up = u'<a href="%s/move_up">\u2191</a>' % object.pk
+        absolute_url = page.get_absolute_url()
+        if absolute_url:
+            view_on_site += u'<a href="%s" title="%s" target="_blank"><img src="%sfiber/admin/images/world.gif" width="16" height="16" alt="%s" /></a>' % \
+                       (absolute_url, _('View on site'), settings.STATIC_URL, _('View on site'))
 
-        # last child cannot be moved down
-        if (not object.is_last_child()):
-            move_down = u'<a href="%s/move_down">\u2193</a>' % object.pk
+        return view_on_site
 
-        return move_up + move_down
+    view_on_site.short_description = ''
+    view_on_site.allow_tags = True
 
-    move_links.short_description = 'Move'
-    move_links.allow_tags = True
+
+    def action_links(self, page):
+        actions = ''
+
+        # first child cannot be moved up, last child cannot be moved down
+        if not page.is_first_child():
+            actions += u'<a href="%s/move_up" title="%s"><img src="%sfiber/admin/images/arrow_up.gif" width="16" height="16" alt="%s" /></a> ' % (page.pk, _('Move up'), settings.STATIC_URL, _('Move up'))
+        else:
+            actions += u'<img src="%sfiber/admin/images/blank.gif" width="16" height="16" alt="" /> ' % (settings.STATIC_URL,)
+            
+        if not page.is_last_child():
+            actions += u'<a href="%s/move_down" title="%s"><img src="%sfiber/admin/images/arrow_down.gif" width="16" height="16" alt="%s" /></a> ' % (page.pk, _('Move down'), settings.STATIC_URL, _('Move down'))
+        else:
+            actions += u'<img src="%sfiber/admin/images/blank.gif" width="16" height="16" alt="" /> ' % (settings.STATIC_URL,)
+
+        # add subpage
+        actions += u'<a href="add/?%s=%s" title="%s"><img src="%sfiber/admin/images/page_new.gif" width="16" height="16" alt="%s" /></a> ' % \
+                   (self.model._mptt_meta.parent_attr, page.pk, _('Add sub page'), settings.STATIC_URL, _('Add sub page'))
+
+        return actions
+
+    action_links.short_description = _('Actions')
+    action_links.allow_tags = True
 
 
 admin.site.register(Page, PageAdmin)
 
 
+class FiberAdminPageForm(PageForm):
+    template_name = forms.ChoiceField(choices=TEMPLATE_CHOICES, required=False, label=_('Template'))
+
+
 class FiberAdminPageAdmin(MPTTModelAdmin):
 
+    form = FiberAdminPageForm
+
     def __init__(self, *args, **kwargs):
         super(FiberAdminPageAdmin, self).__init__(*args, **kwargs)
 
-        # remove template choices, if there are no choices
+        # remove template choices if there are no choices
         if len(TEMPLATE_CHOICES) == 0:
             self.fieldsets =  (
                 (None, {'fields': ('title', 'url', 'redirect_page')}),
@@ -109,8 +125,6 @@ class FiberAdminPageAdmin(MPTTModelAdmin):
                 (None, {'fields': ('title', 'url', 'template_name', 'redirect_page')}),
             )
 
-    form = PageForm
-
     def save_model(self, request, obj, form, change):
         if 'before_page_id' in request.POST:
             before_page = Page.objects.get(pk=int(request.POST['before_page_id']))
